package app.instantLogin;

import app.ApiController;
import app.saaspass.SaaspassApiService;
import app.saaspass.error.RestApiException;
import app.security.JWTToken;
import app.security.TokenProvider;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.messaging.simp.SimpMessagingTemplate;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RestController;

@RestController
class InstantLoginController extends ApiController {

	private static final Logger log = LoggerFactory.getLogger(InstantLoginController.class);

	@Autowired
	private SaaspassApiService saaspassApiService;

	@Autowired
	private SimpMessagingTemplate simpMessagingTemplate;

	@Autowired
	private TokenProvider tokenProvider;

	/**
	 * Method handling Instant Login Post by SAASPASS.
	 * Provide URL for this method under manage application > login services.
	 */
	@PostMapping("/instant-login")
	private ResponseEntity<?> instantLogin(@RequestHeader String username, @RequestHeader String session,
			@RequestHeader String tracker) {
		log.info("/instant-login {username: {}, session: {}, tracker: {}}", username, session, tracker);
			saaspassApiService.checkInstantLoginTracker(username, tracker);

		String destination = "/topic/instant-login/" + session;
		JWTToken payload = new JWTToken(tokenProvider.createAdminToken(username, true));
		simpMessagingTemplate.convertAndSend(destination, payload);

		return ResponseEntity.ok(null);
	}


	/**
	 * Method handling Single Sign On get request by SAASPASS.
	 * Provide URL for this method under manage application > login services.
	 */
	@GetMapping("/sso")
	private ResponseEntity<?> sso(TrackerRequest request) {

		log.info("/sso {account: {}, tracker: {}}", request.getAccount(), request.getTracker());

			saaspassApiService.checkInstantLoginTracker(request.getAccount(), request.getTracker());
		

		String token = tokenProvider.createAdminToken(request.getAccount(), true);
		return ResponseEntity.ok(new JWTToken(token));
	}

}
