package app.manageCompanyAccount;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import app.ApiController;
import app.saaspass.SaaspassApiService;
import app.saaspass.SpAccountResponse;
import app.saaspass.error.RestApiException;

/**
 * Rest controller for account management in the company.
 * These methods are not restricted to be called from inside application only.
 *
 */
@RestController
public class ManageCompanyAccountController extends ApiController {



	private static final Logger log = LoggerFactory.getLogger(ManageCompanyAccountController.class);

	@Autowired
	SaaspassApiService saaspassApiService;

	@PostMapping("/add-account")
	private ResponseEntity<?> addAccount(@RequestBody AddAccountRequest request) {
		try {
			SpAccountResponse addAccountResponse = saaspassApiService.addCompanyAccount(request.getUsername(),
					request.getGroupList(), request.getAccountOwner());
			return ResponseEntity.ok(addAccountResponse);
		} catch (RestApiException e) {
			return ResponseEntity.status(e.getStatusCode()).body(e.getErrorResponse());
		}
	}
	
	@PostMapping("/verify-account")
	private ResponseEntity<?> verifyAccount(@RequestBody VerifyAccountRequest request) {
		SpAccountResponse data = saaspassApiService.verifyAccount(request.getUsername(), request.getAccountOwner(),
				request.getIsAdAccount());
		return ResponseEntity.ok(data);

	}
	

	@PostMapping("/remove-account")
	private ResponseEntity<?> removeAccount(@RequestBody RemoveAccountRequest request) {
		SpAccountResponse data = saaspassApiService.removeAccount(request.getUsername());
		return ResponseEntity.ok(data);

	}

}
