package app.registration;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RestController;

import app.ApiController;
import app.saaspass.SpAccountResponse;

@RestController
public class RegistrationController extends ApiController {

	private static final Logger log = LoggerFactory.getLogger(RegistrationController.class);

	@Autowired
	private RegistrationService registrationService;

	@PostMapping("/register-by-admin")
	private ResponseEntity<?> registerByAdmin(@RequestBody RegisterByAdminRequest request) {
		SpAccountResponse data = registrationService.registerUserByAdmin(request.getUsername(),
				request.getAccountowner(), request.getIsadaccount());
		return ResponseEntity.ok(data);
	}

	@PostMapping("/register-by-user")
	private ResponseEntity<?> registerByUser(@RequestBody RegisterByUserRequest request) {
		return ResponseEntity.ok(registrationService.registerAndLoginUser(request.getUsername(),
				request.getSaaspassId(), request.getOtp()));

	}

	@PostMapping("/password-register-by-user")
	private ResponseEntity<?> registerWithPasswordByUser(@RequestBody RegisterPassByUserRequest request) {
		return ResponseEntity.ok(registrationService.registerAndLoginUser(request.getUsername(), request.getPassword(),
				request.getSaaspassId(), request.getOtp()));

	}

	@PostMapping("/register-password-only")
	private ResponseEntity<?> registerWithPassword(@RequestBody RegisterPassByUserRequest request) {
		registrationService.registerUserWithPassword(request.getUsername(), request.getPassword());
		return ResponseEntity.ok().build();

	}

	@PostMapping("/instant-registration")
	private ResponseEntity<?> instantRegister(@RequestHeader String username, @RequestHeader String session,
			@RequestHeader String tracker) {
		log.info("/instant-registration {username: {}, session: {}, tracker: {}}", username, session, tracker);

		registrationService.instantRegistration(username, session, tracker);

		return ResponseEntity.ok(null);
	}

	@PostMapping("/unregister")
    private ResponseEntity<?> unregister(@RequestBody UnregistrationRequest request) {
            SpAccountResponse data =registrationService.unregisterUser(request.getUsername());
            return ResponseEntity.ok(data);
    }
}
