package app.saaspass;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;


/**
 * Provider for all URLs for SAASPASS rest api.
 *
 */
@Component
public class RestApiUlrProvider {

	private static final Logger log = LoggerFactory.getLogger(RestApiUlrProvider.class);
	
	@Value("${saaspass.api.url}")
    private  String spApiUrl;
	
	/** See <a href="https://developers.saaspass.com/#company-key">https://developers.saaspass.com/#company-key</a> */
	@Value("${saaspass.company.key}")
    private String spCompanyKey;
	/**See <a href="https://developers.saaspass.com/#company-secret"> https://developers.saaspass.com/#company-secret</a>*/
	@Value("${saaspass.company.secret}")
    private String spCompanySecret;

	/**See <a href="https://developers.saaspass.com/#application-key">https://developers.saaspass.com/#application-key</a> */
    @Value("${saaspass.app.key}")
    private  String spAppKey;
    
    /** <a href="https://developers.saaspass.com/#application-password">https://developers.saaspass.com/#application-password</a>*/
    @Value("${saaspass.app.password}")
    private  String spAppPassword;
	
    
    /**
     * See <a href="https://developers.saaspass.com/#generate-company-scope-token">https://developers.saaspass.com/#generate-company-scope-token</a>
     */
	public String getCompanyTokenUrl() {
	
	    String url = String.format(
	        "%s/%s/tokens?companysecret=%s",
	        spApiUrl,
	        spCompanyKey,
	        spCompanySecret
	    );
	
	    log.debug(url);
	
	    return url;
	
	}
	
	 /**
	 * See <a href="https://developers.saaspass.com/#application-scope-token">https://developers.saaspass.com/#application-scope-token</a>
	 */
	public  String getApplicationTokenUrl() {

        String url = String.format(
            "%s/applications/%s/tokens?password=%s",
            spApiUrl,
            spAppKey,
            spAppPassword
        );

        log.debug(url);

        return url;
    }
	
	/**
	 * See <a href="https://developers.saaspass.com/#get-barcode-request">https://developers.saaspass.com/#get-barcode-request</a>
	 */
	public String getBarcodeUrl(BarcodeType barcodeType,String session, String token) {
	
	    String url = String.format(
	        "%s/applications/%s/barcodes?type=%s&session=%s&token=%s",
	        spApiUrl,
	        spAppKey,
	        barcodeType,
	        session,
	        token
	    );
	
	    log.debug(url);
	
	    return url;
	}
	
	/**
	 * See <a href="https://developers.saaspass.com/#get-push-login-request">https://developers.saaspass.com/#get-push-login-request</a>
	 */
	public String getPushUrl(String username,String session, String token) {
	
	    String url = String.format(
	        "%s/applications/%s/push?username=%s&session=%s&token=%s",
	        spApiUrl,
	        spAppKey,
	        username,
	        session,
	        token
	    );
	
	    log.debug(url);
	
	    return url;
	}
	
	/**
	 * See <a href="https://developers.saaspass.com/#otp-check-request">https://developers.saaspass.com/#otp-check-request</a>
	 */
	public String getOtpCheckUrl(String username,String otp, String token) {
	
	    String url = String.format(
	        "%s/applications/%s/otpchecks?username=%s&otp=%s&token=%s",
	        spApiUrl,
	        spAppKey,
	        username,
	        otp,
	        token
	    );
	
	    log.debug(url);
	
	    return url;
	}
	
	/** 
	 * See <a href="https://developers.saaspass.com/#trackerid-request">https://developers.saaspass.com/#trackerid-request</a>
	 */
	public String getInstantLoginTrackerUrl(String username,String tracker, String token) {
	
	    String url = String.format(
	        "%s/applications/%s/trackers/%s?account=%s&token=%s",
	        spApiUrl,
	        spAppKey,
	        tracker,
	        username,
	        token
	    );
	
	    log.debug(url);
	
	    return url;
	}
	
	/**
	 * See <a href="https://developers.saaspass.com/#register-account-by-user-request">https://developers.saaspass.com/#register-account-by-user-request</a>
	 */
	public String getAddApplicationAccountByUserUrl(String username,String otp,String saaspassId,boolean isAdAccount, String token) {
	
	    String url = String.format(
	        "%s/applications/%s/registerbyuser?username=%s&saaspassid=%s&otp=%s&isadaccount=%s&token=%s",
	        spApiUrl,
	        spAppKey,
	        username,
	        saaspassId,
	        otp,
	        isAdAccount,
	        token
	    );
	
	    log.debug(url);
	
	    return url;
	}
	
	 /**
	 * See <a href="https://developers.saaspass.com/#register-account-by-admin-request">https://developers.saaspass.com/#register-account-by-admin-request</a>
	 */
	public String getAddAccountToApplicationByAdminUrl(String username,String accountOwner,boolean isAdAccount, String token) {
	
	    String url = String.format(
	        "%s/applications/%s/registerbyadmin?username=%s&accountowner=%s&isadaccount=%s&token=%s",
	        spApiUrl,
	        spAppKey,
	        username,
	        accountOwner,
	        isAdAccount,
	        token
	    );
	
	    log.debug(url);
	
	    return url;
	}
	
	 /**
	 * See <a href="https://developers.saaspass.com/#unregister-account92">https://developers.saaspass.com/#unregister-account92</a>
	 */
	public String getUnregisterAccountUrl(String username, String token) {
	
	    String url = String.format(
	        "%s/applications/%s/unregister?username=%s&token=%s",
	        spApiUrl,
	        spAppKey,
	        username,
	        token
	    );
	
	    log.debug(url);
	
	    return url;
	}
	
	/**
	 * See <a href="https://developers.saaspass.com/#add-account-request">https://developers.saaspass.com/#add-account-request</a>
	 */
	public String getAddCompanyAccountUrl(String username,String groupList,String accountOwner, String token) {

        String url = String.format(
            "%s/%s/addaccount?username=%s&grouplist=%s&accountowner=%s&token=%s",
            spApiUrl,
            spCompanyKey,
            username,
            groupList,
            accountOwner,
            token
        );

        log.debug(url);

        return url;
    }
	
	 /**
	 * See <a href="https://developers.saaspass.com/#remove-account-request">https://developers.saaspass.com/#remove-account-request</a>
	 */
	public String getRemoveAccountUrl(String username, String token) {

			String url = String.format(
					"%s/%s/removeaccount?username=%s&token=%s", 
					spApiUrl, 
					spCompanyKey, 
					username,
					token);

			log.debug(url);

			return url;
		}
	
		/**
		 * See <a href="https://developers.saaspass.com/#verify-account-request">https://developers.saaspass.com/#verify-account-requests</a>
		 */
		public String getVeryfyAccountUrl(String username, String accountOwner, Boolean isAdAccount, String token) {

			String url = String.format("%s/%s/verifyaccount?username=%s&accountowner=%s&isadaccount=%s&token=%s",
					spApiUrl, 
					spCompanyKey, 
					username, 
					accountOwner, 
					isAdAccount, 
					token);

			log.debug(url);

			return url;
		}
}
