package app.saaspass.error;

import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.ObjectMapper;

import org.springframework.http.client.ClientHttpResponse;
import org.springframework.web.client.DefaultResponseErrorHandler;

import java.io.IOException;
import java.util.Map;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static org.springframework.http.HttpStatus.TOO_MANY_REQUESTS;

public class MyResponseErrorHandler extends DefaultResponseErrorHandler {

    @Override
    public void handleError(ClientHttpResponse response) throws IOException {
        try {
            SaaspassErrorResponse errorResponse = new ObjectMapper().readValue(response.getBody(), SaaspassErrorResponse.class);

            if (response.getStatusCode() == TOO_MANY_REQUESTS) {
                Map<String, String> headers = Stream.of(
                    "X-Rate-Limit-Limit",
                    "X-Rate-Limit-Resets",
                    "X-Rate-Limit-Remaining"
                ).filter(
                    response.getHeaders()::containsKey
                ).collect(Collectors.toMap(
                    header -> header,
                    header -> response.getHeaders().get(header).get(0)
                ));

                errorResponse.setHeaders(headers);
            }

            throw new RestApiException(response.getStatusCode(), errorResponse);

        } catch (JsonParseException e) {
            String message = response.getRawStatusCode() + " - " + response.getStatusText();
            throw new RestApiException(response.getStatusCode(), new SaaspassErrorResponse(message));
        }
    }
}
