package app.saaspass.token;

import java.time.Duration;
import java.time.Instant;

/**
 * See <a href="https://developers.saaspass.com/#generate-company-scope-token"> https://developers.saaspass.com/#generate-company-scope-token</a>
 *
 */
class CompanyToken implements SaaspassToken {

	private String tokenValue;
	private Instant expiresOn;
	private Integer numberUsed;

	@Override
	public synchronized void refreshToken(String tokenValue, Instant createdOn) {
		this.tokenValue = tokenValue;
		this.expiresOn = createdOn.plus(Duration.ofHours(1));
		this.numberUsed = 1;
	}

	@Override
	public synchronized String useToken() {
		if (isExpired()) {
			return null;
		}
		numberUsed = numberUsed + 1;
		return tokenValue;
	}

	private boolean isExpired() {
		return tokenValue == null || numberUsed >= 100 || Instant.now().isAfter(expiresOn);
	}

}
