package app.security;

import org.springframework.context.annotation.Configuration;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;

import static org.springframework.http.HttpMethod.OPTIONS;

@Configuration
public class SecurityConfiguration extends WebSecurityConfigurerAdapter {

    private final TokenProvider tokenProvider;

    public SecurityConfiguration(TokenProvider tokenProvider) {
        this.tokenProvider = tokenProvider;
    }

    @Override
    protected void configure(HttpSecurity http) throws Exception {
        http.csrf().disable()
            .authorizeRequests()
            .antMatchers(OPTIONS, "/**").permitAll()
            .antMatchers("/api/register-by-admin").hasRole("ADMIN")
            .antMatchers("/api/remove-account").hasRole("ADMIN")
            .antMatchers("/api/unregister").hasRole("ADMIN")
            .antMatchers("/api/verify-account").hasRole("ADMIN")
            .antMatchers("/**").permitAll()
            .and().apply(securityConfigurerAdapter());
    }

    private JWTConfigurer securityConfigurerAdapter() {
        return new JWTConfigurer(tokenProvider);
    }
}
