import {app} from '../app';
import {apiUrl} from '../config/api-url.config';
import {LoginRequest, LoginResponse} from '../public/login/login.model';
import {LoginPasswordRequest} from '../public/login/login.model';
import {Principal} from './principal.model';

export class AuthService {

    private principal: Principal;

    /** @ngInject */
    constructor(private $http: ng.IHttpService,
                private $q: ng.IQService) {
    }

    init() {
        const token: string = localStorage.getItem('token');
        if (token) {
            this.setToken(token);
        } else {
            this.logout();
        }
    }

    login(request: LoginRequest): ng.IPromise<Principal> {

        return this.$http.post<LoginResponse>(
            `${apiUrl}/login`, request
        ).then(response => {
            this.setToken(response.data.token);
            return this.principal;
        });
    }

	loginWithPass(request: LoginPasswordRequest): ng.IPromise<Principal> {

        return this.$http.post<LoginResponse>(
            `${apiUrl}/passwordLogin`, request
        ).then(response => {
            this.setToken(response.data.token);

            return this.principal;
        });
    }

    logout() {
        localStorage.clear();
        this.principal = undefined;
    }

    isLoggedIn(): boolean {
        return !!this.principal;
    }

    setToken(token: string) {
        localStorage.setItem('token', token);
        try {
            this.principal = Principal.fromJwt(token);
        } catch (e) {
            // logout if invalid token
            this.logout();
        }
    }

    getPrincipal(): ng.IPromise<Principal> {
        if (this.principal) {
            return this.$q.resolve(this.principal);
        } else {
            return null;
        }
    }
}

app.service('AuthService', AuthService);
