import { AuthService } from '../../../auth/auth.service';
import { BarcodeService } from '../../../barcode/barcode.service';
import { ErrorResponse } from '../../../response.model';
import { LoginRequest } from '../login.model';
import { PushService } from '../push.service';

export class LoginController {


	request: LoginRequest;
	barcodeImage: string;
	bluetoothCode: string;

	/** @ngInject */
	constructor(private $state: ng.ui.IStateService,
		private toastr: Toastr,
		private BarcodeService: BarcodeService,
		private AuthService: AuthService,
		private $sce: ng.ISCEService,
		private PushService: PushService) {

		this.BarcodeService.barcodeImageandBluetoothcode().then(response =>{
			this.barcodeImage = response.image;
			this.bluetoothCode= $sce.trustAsResourceUrl(response.bluepass);
		});
	}

	login() {
		this.AuthService.login(this.request).then(response => {
			const json = JSON.stringify(response, null, ' ');
			this.toastr.success(`<pre>${json}</pre>`);
			this.$state.go('app.admin');
		}).catch((response: ng.IHttpPromiseCallbackArg<ErrorResponse>) => {
			const json = JSON.stringify(response.data, null, ' ');
			this.toastr.error(`<pre>${json}</pre>`);
		});
	}

	pushLogin() {
		this.PushService.push(this.request.username).then(response =>
			this.toastr.info('Successfully sent push-login request. Please check your device.')
		).catch((response: ng.IHttpPromiseCallbackArg<ErrorResponse>) => {
			const json = JSON.stringify(response.data, null, ' ');
			this.toastr.error(`<pre>${json}</pre>`);
		});
	}
}
