import { BarcodeService } from '../../../barcode/barcode.service';
import { ErrorResponse } from '../../../response.model';
import { AuthService } from '../../../auth/auth.service';
import { RegisterByUserRequest } from '../register.model';
import { LoginResponse } from '../../login/login.model';
import { SpResponse } from '../../../response.model';
import { RegisterByUserService } from '../register.service';

export class RegisterByUserController {

	request: RegisterByUserRequest;
	barcode: string;
	ilir: boolean;

	/** @ngInject */
	constructor(private $state: ng.ui.IStateService,
		private toastr: Toastr,
		private AuthService: AuthService,
		private RegisterByUserService: RegisterByUserService,
		private BarcodeService: BarcodeService) {

		this.BarcodeService.barcodeImage('IR')
			.then((image: string) => this.barcode = image);
	}

	register() {
		this.RegisterByUserService.register(this.request).then(response => {
			const json = JSON.stringify(response, null, ' ');
			let keyList = Object.keys(response);
			if (keyList.length > 0) {
				if (keyList.indexOf('token') !== -1) {
					var loginToken = <LoginResponse>response;
					this.AuthService.setToken(loginToken.token);
					this.toastr.success(`<pre>${json}</pre>`);
					this.$state.go('app.admin');
				} else {
					var spResponse = <SpResponse>response;
					if (spResponse.warning) {
						this.toastr.warning(`<pre>${json}</pre>`);
					} else {
						this.toastr.success(`<pre>${json}</pre>`);
					}
				}
			}
		}).catch((response: ng.IHttpPromiseCallbackArg<ErrorResponse>) => {
			const json = JSON.stringify(response.data, null, ' ');
			this.toastr.error(`<pre>${json}</pre>`);
		});
	}

	refreshBarcode() {
		this.BarcodeService
			.barcodeImage(this.ilir ? 'ILIR' : 'IR')
			.then(image => this.barcode = image);
	}
}
