import { AuthService } from '../auth/auth.service';
import { ErrorResponse } from '../response.model';
import { Principal } from '../auth/principal.model';
import { LoginRequest } from '../public/login/login.model';
import { PushService } from '../public/login/push.service';
import { BarcodeService } from '../barcode/barcode.service';

export class SecondStepLoginController {
	request: LoginRequest;
	barcodeImage: string;
	bluetoothCode: string;

	/** @ngInject */
	constructor(private $state: ng.ui.IStateService,
		private $sce: ng.ISCEService,
		private toastr: Toastr,
		private AuthService: AuthService,
		private BarcodeService: BarcodeService,
		private PushService: PushService,
		private principal: Principal) {
		this.BarcodeService.barcodeImage('IL')
			.then(image => this.barcodeImage = image);


	}

	getUsername(): string {
		return this.principal.username;
	}

	logout() {
		this.AuthService.logout();
		this.$state.go('app.login.saaspass');
		this.toastr.success('logout successful');
	}

	login() {
		this.request.username = this.getUsername();
		this.AuthService.login(this.request).then(response => {
			const json = JSON.stringify(response, null, ' ');
			this.toastr.success(`<pre>${json}</pre>`);
			this.$state.go('app.admin');
		}).catch((response: ng.IHttpPromiseCallbackArg<ErrorResponse>) => {
			const json = JSON.stringify(response.data, null, ' ');
			this.toastr.error(`<pre>${json}</pre>`);
		});
	}

	pushLogin() {
		this.PushService.push(this.request.username).then(response =>
			this.toastr.info('Successfully sent push-login request. Please check your device.')
		).catch((response: ng.IHttpPromiseCallbackArg<ErrorResponse>) => {
			const json = JSON.stringify(response.data, null, ' ');
			this.toastr.error(`<pre>${json}</pre>`);
		});
	}
}
